.. class:: center

   .. image:: https://github.com/5hulse/bruker_utils/workflows/build/badge.svg
     :target: https://github.com/5hulse/bruker_utils/actions?query=workflow%3Abuild

   .. image:: https://img.shields.io/badge/License-MIT-yellow.svg
      :target: https://opensource.org/licenses/MIT

**bruker_utils**: Module for handling Bruker NMR data in Python.

This package provides a number of features to make handling Bruker NMR data
in Python straightforward.

Documentation: https://5hulse.github.io/bruker_utils/
